==> plexus-containers1.5_1.6.orig.tar.gz: plexus-containers-plexus-containers-1.6/plexus-component-annotations/src/main/java/org/codehaus/plexus/component/annotations/Component.java <==
/*
 * Copyright (C) 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.codehaus.plexus.component.annotations;

import java.lang.annotation.Documented;
import static java.lang.annotation.ElementType.TYPE;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import static java.lang.annotation.RetentionPolicy.RUNTIME;
import java.lang.annotation.Target;

/**
 * Marks a class as a Plexus component.
 *
 * @since 1.0-alpha-33
 * @version $Id$
 */
@Documented
@Retention(RUNTIME)
@Target(TYPE)
@Inherited
public @interface Component
{
    Class<?> role();

    String hint() default "";

    String version() default "";

    String alias() default "";

    String description() default "";

    String lifecycleHandler() default "";

    String instantiationStrategy() default "";

    String factory() default "";

    String type() default "";

    String profile() default "";

    String composer() default "";

    String configurator() default "";

    boolean isolatedRealm() default false;
}

==> plexus-containers-2.2.0.tar.gz: plexus-containers-plexus-containers-2.2.0/plexus-component-annotations/src/main/java/org/codehaus/plexus/component/annotations/Component.java <==
/*
 * Copyright (C) 2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.codehaus.plexus.component.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

/**
 * Marks a class as a Plexus component.
 *
 * @since 1.0-alpha-33
 * @deprecated see <a href="https://github.com/eclipse/sisu.plexus/wiki/Plexus-to-JSR330">Plexus-to-JSR330</a> instead.
 */
@Documented
@Retention(RUNTIME)
@Target(TYPE)
@Inherited
@Deprecated
public @interface Component {
    Class<?> role();

    String hint() default "";

    String version() default "";

    String alias() default "";

    String description() default "";

    String lifecycleHandler() default "";

    String instantiationStrategy() default "";

    String factory() default "";

    String type() default "";

    String profile() default "";

    String composer() default "";

    String configurator() default "";

    boolean isolatedRealm() default false;
}
